import { Component, OnInit } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { MatDialog } from '@angular/material/dialog';
import { CommandDetailComponent } from './command-detail/command-detail/command-detail.component';
import { CreateCommandComponent } from './create-command/create-command.component';

@Component({
  selector: 'app-commands',
  templateUrl: './commands.component.html',
  styleUrls: ['./commands.component.css']
})
export class CommandsComponent implements OnInit {
  commands: any[] = [];
  displayedColumns: string[] = ['name', 'createdBy', 'createdAt'];
  private apiUrl = 'http://127.0.0.1:8001/commands?page=1&itemsPerPage=30';

  constructor(private http: HttpClient, private dialog: MatDialog) { }

  ngOnInit(): void {
    this.loadCommands();
  }

  loadCommands(): void {
    this.http.get<any>(this.apiUrl).subscribe(
      (data) => {
        this.commands = data['hydra:member'];
      },
      (error) => {
        console.error('Error fetching commands', error);
      }
    );
  }

  openCommandDetailModal(command: any): void {
    const dialogRef = this.dialog.open(CommandDetailComponent, {
      width: '800px',
      data: command
    });

    dialogRef.afterClosed().subscribe(result => {
      this.loadCommands();
    });
  }

  openCreateCommandModal(): void {
    const dialogRef = this.dialog.open(CreateCommandComponent, {
      width: '600px'
    });

    dialogRef.afterClosed().subscribe(result => {
      this.loadCommands();
    });
  }

  
}
